@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertCodeOutput;
 
-our $DATE = '2014-12-12'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-01-25'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,6 +17,8 @@ with (
     },
 );
 
+has verbatim => (is => 'rw', default => sub{1});
+
 use namespace::autoclean;
 
 sub munge_files {
@@ -47,7 +49,7 @@ sub _code_output {
         die "eval '$code' failed: $@";
     }
 
-    $merged =~ s/^/ /gm;
+    $merged =~ s/^/ /gm if $self->verbatim;
     $merged;
 }
 
@@ -67,13 +69,14 @@ Dist::Zilla::Plugin::InsertCodeOutput - Insert the output of Perl code into your
 
 =head1 VERSION
 
-This document describes version 0.01 of Dist::Zilla::Plugin::InsertCodeOutput (from Perl distribution Dist-Zilla-Plugin-InsertCodeOutput), released on 2014-12-12.
+This document describes version 0.02 of Dist::Zilla::Plugin::InsertCodeOutput (from Perl distribution Dist-Zilla-Plugin-InsertCodeOutput), released on 2015-01-25.
 
 =head1 SYNOPSIS
 
 In dist.ini:
 
  [InsertCodeOutput]
+ ;verbatim=1
 
 In your POD:
 
@@ -83,8 +86,10 @@ In your POD:
 
 This module finds C<# CODE: ...> directives in your POD, evals the specified
 Perl code while capturing the output using L<Capture::Tiny>'s C<capture_merged>
-(which means STDOUT and STDERR output are both captured). If eval fails (C<$@>
-is true), build will be aborted.
+(which means STDOUT and STDERR output are both captured), and insert the output
+to your POD as verbatim paragraph (indented with a whitespace), unless when
+C<verbatim> is set to 0 then it is inserted as-is. If eval fails (C<$@> is
+true), build will be aborted.
 
 =for Pod::Coverage .+
 
@@ -121,7 +126,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
